#
#
#    tailall.py
#
#    Python utility for following and parsing the ALL.LOG file.
#
#    Copyright (C) 2019 by Matt Roberts.
#    License: GNU GPL3 (www.gnu.org)
#
#

from taillog import *
import callsigns
import time

def tailall(path, callback):
	def inner_callback(line):
		if not line:
			return
		line = line.strip()
		if not line:
			return
		parts = line.split()
		if len(parts) < 8:
			return

		result = { }
		if parts[2] != 'Rx' and parts[2] != 'Tx':
			return
		result['date'], result['time'] = parts[0].split('_')
		result['freq'] = parts[1]
		result['tx'] = (parts[2] == 'Tx')
		result['rx'] = (parts[2] == 'Rx')
		result['mode'] = parts[3]
		result['snr'] = parts[4]
		result['dt'] = parts[5]
		result['audio'] = parts[6]
		result['what'] = [ ]
		result['ts'] = time.time()
		rawwhat = parts[7:]
		for i in rawwhat:
			if i.startswith('<'):
				i = i[1:]
			if i.endswith('>'):
				i = i[:-1]
			result['what'].append(i)

		# try to parse out calls
		calls = [ ]
		result['to'] = None
		result['from'] = None
		result['cq'] = False
		is_cq = False
		if len(result['what']) > 0:
			is_cq = result['what'][0].startswith('CQ')
			for i in result['what']:
				if callsigns.iscall(i):
					calls.append(i)
			if len(calls) == 2:
				result['to'] = calls[0]
				result['from'] = calls[1]
			elif len(calls) == 1 and is_cq:
				result['from'] = calls[0]
				result['cq'] = True
		
		# callback with the filled dictionary
		callback(result)
		
	# run the tail with the callback above
	p = taillog(path, inner_callback)


#
#  unit tests
#
if __name__ == '__main__':
	# the test file
	fn = '~/.local/share/WSJT-X/ALL.TXT'

	# the callback
	def callback(d):
		sys.stdout.write('Dict: "%s"\n' % str(d))

	# the test
	fn = os.path.expanduser(fn) 
	tailall(fn, callback)
