#
#
#    taillog.py
#
#    Python utility for following and parsing changes in a text file.
#
#    Copyright (C) 2019 by Matt Roberts.
#    License: GNU GPL3 (www.gnu.org)
#
#

import sys
import os
import os.path
import subprocess
import time


#
#  split_tail(s) - for compound messages, split into two
#
def split_tail(s):
	if not s:
		return []
	msgs = s.split(';')
	result = [ ]
	if len(msgs) == 2:
		parts0 = msgs[0].strip().split(' ', 2)
		parts1 = msgs[1].strip().split(' ', 2)
		if len(parts1) == 3 and len(parts0) == 2:
			result.append("%s %s %s" % (parts0[0], parts1[1], parts0[1]))
			result.append("%s %s %s" % (parts1[0], parts1[1], parts1[2]))
		else:
			result = msgs
	else:
		result = msgs
	return result


#
#  taillog(path, callback)
#
def taillog(path, callback):
	pid = os.getpid()
	p = subprocess.Popen(['tail', '-n', '0', '--pid', str(pid), '-f', path], stdout=subprocess.PIPE)
	try:
		while p:
			l = p.stdout.readline()
			if not l: return
			l = l.strip()
			if not l: continue
			l = l.decode("utf-8") 
			l = split_tail(l)
			if callback:
				for msg in l:
					try:
						callback(msg)
					except:
						pass
	except:
		pass
	finally:
		p.stdout.close()


#
#  unit tests
#
if __name__ == '__main__':
	# test split
	compound = 'PY2EW RR73; K4RDZ <4U1UN> -08'
	msgs = split_tail(compound)
	sys.stdout.write("split_tail(%s) => %s\n" % (compound, msgs))

	# the test file
	fn = '~/.local/share/WSJT-X/ALL.TXT'

	# the callback
	def callback(line):
		sys.stdout.write('Line: "%s"\n' % line)

	# the test
	fn = os.path.expanduser(fn) 
	taillog(fn, callback)

# EOF
